;; debian/theme.jl
;; (copied from gradient/theme.jl)
;; $Id: theme.jl,v 1.17 1999/11/25 23:38:41 john Exp $

;; Copyright (C) 1999 John Harper <john@dcs.warwick.ac.uk>

;; This file is part of sawmill.

;; sawmill is free software; you can redistribute it and/or modify it
;; under the terms of the GNU General Public License as published by
;; the Free Software Foundation; either version 2, or (at your option)
;; any later version.

;; sawmill is distributed in the hope that it will be useful, but
;; WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with sawmill; see the file COPYING.  If not, write to
;; the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.

(require 'gradient)

;; Commentary:

(let* ((bevel-percent 40)
       (render-title-bar
	(lambda (img state)
	  (if state
	      (draw-horizontal-gradient img
					(get-color "#620819")
					(get-color "#850b22"))
	      (draw-horizontal-gradient img
					(get-color "#8c816d")
					(get-color "#c6b9ae")))
	  (bevel-image img 1 t bevel-percent)
	  (set-image-border img 1 1 1 1)))
       (render-bottom-border
	(lambda (img state)
	  (clear-image img (get-color "#a9a99d9d8e8e"))
	  (bevel-image img 1 t bevel-percent)
	  (set-image-border img 1 1 1 1)))
       (render-iconify-button
	(lambda (img state)
	  (if state
	      (clear-image img (get-color "#620819"))
	      (clear-image img (get-color "#8c816d")))
	  (bevel-image img 1 t bevel-percent)
	  (set-image-border img 1 1 1 1)))
       (render-close-button
	(lambda (img state)
	  (if state
	      (clear-image img (get-color "#850b22"))
	      (clear-image img (get-color "#c6b9ae")))
	  (bevel-image img 1 t bevel-percent)
	  (set-image-border img 1 1 1 1)))

       (iconify-image
	(let ((image (make-image "min21.png")))
	  (set-image-shape-color image (get-color "#000000"))
	  image))
       (close-image
	(let ((image (make-image "close21.png")))
	  (set-image-shape-color image (get-color "#000000"))
	  image))

       (title-bar-height 21)
       (title-bar-top (- -1 title-bar-height))
       (bottom-border-height 7)
       (bottom-border-bottom (- -1 bottom-border-height))
       (bottom-corner-width 29)
       (frame-top (- title-bar-top 1))
       (frame-bottom (- bottom-border-bottom 1))

       (title-bar
	`(((class . title)
	   (left-edge . ,title-bar-height)
	   (right-edge . ,title-bar-height)
	   (top-edge . ,title-bar-top)
	   (height . ,title-bar-height)
	   (renderer . ,render-title-bar)
	   (foreground "black" "white" "white" "white")
	   (text . ,window-name)
	   (x-justify . center)
	   (y-justify . center)
	   (cursor . left_ptr))
	  ((class . iconify-button)
	   (left-edge . 0)
	   (top-edge . ,title-bar-top)
	   (height . ,title-bar-height)
	   (width . ,title-bar-height)
	   (renderer . ,render-iconify-button)
	   (foreground . ,iconify-image)
	   (cursor . left_ptr)
	   (removable . t))
	  ((class . close-button)
	   (right-edge . 0)
	   (top-edge . ,title-bar-top)
	   (height . ,title-bar-height)
	   (width . ,title-bar-height)
	   (renderer . ,render-close-button)
	   (foreground . ,close-image)
	   (cursor . left_ptr)
	   (removable . t))))

       (piping
	(lambda (shaped?)
	  `(((left-edge . 0)
	     (right-edge . 0)
	     (top-edge . ,frame-top)
	     (height . 1)
	     (background . "black"))
	    ((left-edge . 0)
	     (right-edge . 0)
	     (top-edge . -1)
	     (height . 1)
	     (background . "black"))
	    ,@(if shaped?
		  `(((top-edge . ,frame-top)
		     (left-edge . -1)
		     (height . ,(+ title-bar-height 2))
		     (width . 1)
		     (background . "black"))
		    ((top-edge . ,frame-top)
		     (height . ,(+ title-bar-height 2))
		     (right-edge . -1)
		     (width . 1)
		     (background . "black")))
		  `(((left-edge . 0)
		     (right-edge . 0)
		     (bottom-edge . ,frame-bottom)
		     (height . 1)
		     (background . "black"))
		    ((left-edge . 0)
		     (right-edge . 0)
		     (bottom-edge . -1)
		     (height . 1)
		     (background . "black"))
		    ((top-edge . ,frame-top)
		     (bottom-edge . ,frame-bottom)
		     (left-edge . -1)
		     (width . 1)
		     (background . "black"))
		    ((top-edge . ,frame-top)
		     (bottom-edge . ,frame-bottom)
		     (right-edge . -1)
		     (width . 1)
		     (background . "black")))))))

       (bottom-border
	`(((class . bottom-border)
	   (left-edge . ,bottom-corner-width)
	   (right-edge . ,bottom-corner-width)
	   (bottom-edge . ,bottom-border-bottom)
	   (height . ,bottom-border-height)
	   (renderer . ,render-bottom-border))
	  ((class . bottom-left-corner)
	   (left-edge . 0)
	   (bottom-edge . ,bottom-border-bottom)
	   (width . ,bottom-corner-width)
	   (height . ,bottom-border-height)
	   (renderer . ,render-bottom-border))
	  ((class . bottom-right-corner)
	   (right-edge . 0)
	   (bottom-edge . ,bottom-border-bottom)
	   (width . ,bottom-corner-width)
	   (height . ,bottom-border-height)
	   (renderer . ,render-bottom-border))))
       )

  (add-frame-style 'debian
		   (lambda (w type)
		     (cond ((or (eq type 'shaped)
				(eq type 'shaped-transient))
			    `(,@title-bar ,@(piping t)))
			   ((eq type 'unframed)
			    nil-frame)
			   (t `(,@title-bar ,@(piping nil) ,@bottom-border)))))
  )
